Tinkex.CLI.Commands.Checkpoint (Tinkex v0.3.4)

Checkpoint management commands: save, list, info, publish, unpublish, delete, download.

Summary

Functions

Saves a checkpoint with the given options and dependencies.

Manages checkpoint operations (list, info, publish, unpublish, delete, download).

Functions

run_checkpoint(options, overrides \\ %{})

@spec run_checkpoint(map(), map()) :: {:ok, map()} | {:error, term()}

Saves a checkpoint with the given options and dependencies.

run_checkpoint_management(action, options, overrides \\ %{})

@spec run_checkpoint_management(atom(), map(), map()) ::
  {:ok, map()} | {:error, term()}

Manages checkpoint operations (list, info, publish, unpublish, delete, download).