Tinkex.CLI.Formatting (Tinkex v0.3.4)

Output formatting utilities for the CLI (JSON, table, size formatting, datetime).

Summary

Functions

Converts a checkpoint struct or map to a formatted map.

Formats a datetime value into an ISO 8601 string.

Formats LoRA information for display.

Formats a byte size into a human-readable string (B, KB, MB, GB, TB).

Formats training run status.

Converts a training run struct or map to a formatted map.

Converts weights info to a formatted map.

Functions

checkpoint_to_map(checkpoint)

Converts a checkpoint struct or map to a formatted map.

format_datetime(dt)

Formats a datetime value into an ISO 8601 string.

format_lora(map)

Formats LoRA information for display.

format_size(bytes)

Formats a byte size into a human-readable string (B, KB, MB, GB, TB).

format_status(map)

Formats training run status.

run_to_map(run)

Converts a training run struct or map to a formatted map.

weights_info_to_map(info)

Converts weights info to a formatted map.