Model metadata including architecture, display name, and tokenizer id.
Summary
Functions
Parse model metadata from a JSON map (string or atom keys).
Model metadata including architecture, display name, and tokenizer id.
Parse model metadata from a JSON map (string or atom keys).