Tinkex.Types.SaveWeightsForSamplerRequest (Tinkex v0.3.4)
View SourceRequest to save model weights for use in sampling.
Mirrors Python tinker.types.SaveWeightsForSamplerRequest.
Request to save model weights for use in sampling.
Mirrors Python tinker.types.SaveWeightsForSamplerRequest.