Tinkex.Types.Telemetry.Severity (Tinkex v0.3.4)

Severity level enumeration for telemetry events.

Mirrors Python tinker.types.severity.Severity. Wire format: "DEBUG" | "INFO" | "WARNING" | "ERROR" | "CRITICAL"

Summary

Functions

Parse wire format string to atom.

Convert atom to wire format string.

List all valid severity levels in order of increasing severity.

Types

t()

@type t() :: :debug | :info | :warning | :error | :critical

Functions

parse(arg1)

@spec parse(String.t() | atom() | nil) :: t() | nil

Parse wire format string to atom.

to_string(str)

@spec to_string(t() | String.t()) :: String.t()

Convert atom to wire format string.

values()

@spec values() :: [t()]

List all valid severity levels in order of increasing severity.