Tinkex.Types.Telemetry.TelemetryEvent (Tinkex v0.3.4)

Union type for telemetry events.

Mirrors Python tinker.types.telemetry_event.TelemetryEvent. Can be one of: GenericEvent, SessionStartEvent, SessionEndEvent, UnhandledExceptionEvent.

Summary

Functions

Get the event type of a telemetry event.

Parse wire format map to appropriate struct based on event type.

Convert a telemetry event struct to wire format map.

Types

Functions

event_type(arg1)

@spec event_type(t()) :: Tinkex.Types.Telemetry.EventType.t()

Get the event type of a telemetry event.

from_map(map)

@spec from_map(map()) :: t() | nil

Parse wire format map to appropriate struct based on event type.

to_map(event)

@spec to_map(t()) :: map()

Convert a telemetry event struct to wire format map.